@@ -45,22 +45,62 @@ def LoggerToDupLevel(verb):
        more severe"""
     return DupToLoggerLevel(verb)
 
-def Log(s, verb_level, code=1):
+def Log(s, verb_level, code=1, extra=None, force_print=False):
     """Write s to stderr if verbosity level low enough"""
     global _logger
-    # currentCode is a terrible hack until duplicity depends on Python 2.5
+    # controlLine is a terrible hack until duplicity depends on Python 2.5
     # and its logging 'extra' keyword that allows a custom record dictionary.
-    _logger.currentCode = code
+    if extra:
+        _logger.controlLine = '%d %s' % (code, extra)
+    else:
+        _logger.controlLine = '%d' % (code)
+    if not s:
+        s = '' # If None is passed, standard logging would render it as 'None'
+    
+    if force_print:
+        initial_level = _logger.getEffectiveLevel()
+        _logger.setLevel(DupToLoggerLevel(MAX))
+    
     _logger.log(DupToLoggerLevel(verb_level), s)
-    _logger.currentCode = 1
+    _logger.controlLine = None
+    
+    if force_print:
+        _logger.setLevel(initial_level)
 
 def Debug(s):
     """Shortcut used for debug message (verbosity 9)."""
     Log(s, DEBUG)
 
-def Info(s):
+class InfoCode:
+    """Enumeration class to hold info code values.
+       These values should never change, as frontends rely upon them.
+       Don't use 0 or negative numbers."""
+    generic = 1
+    progress = 2
+    collection_status = 3
+    diff_file_new = 4
+    diff_file_changed = 5
+    diff_file_deleted = 6
+    patch_file_writing = 7
+    patch_file_patching = 8
+    file_list = 9
+
+def Info(s, code=InfoCode.generic, extra=None):
     """Shortcut used for info messages (verbosity 5)."""
-    Log(s, INFO)
+    Log(s, INFO, code, extra)
+
+def Progress(s, current, total=None):
+    """Shortcut used for progress messages (verbosity 5)."""
+    if total:
+        controlLine = '%d %d' % (current, total)
+    else:
+        controlLine = '%d' % current
+    Log(s, INFO, InfoCode.progress, controlLine)
+
+def PrintCollectionStatus(col_stats, force_print=False):
+    """Prints a collection status to the log"""
+    Log(str(col_stats), 8, InfoCode.collection_status,
+        '\n' + '\n'.join(col_stats.to_log_info()), force_print)
 
 def Notice(s):
     """Shortcut used for notice messages (verbosity 3, the default)."""
@@ -86,39 +126,67 @@ class ErrorCode:
        These values should never change, as frontends rely upon them.
        Don't use 0 or negative numbers.  This code is returned by duplicity
        to indicate which error occurred via both exit code and log."""
-    generic = 1
+    generic = 1 # Don't use if possible, please create a new code and use it
     command_line = 2
     source_mismatch = 3
+    no_manifests = 4
+    mismatched_manifests = 5
+    unreadable_manifests = 6
+    cant_open_filelist = 7
+    bad_url = 8
+    bad_archive_dir = 9
+    bad_sign_key = 10
+    restore_dir_exists = 11
+    verify_dir_doesnt_exist = 12
+    backup_dir_doesnt_exist = 13
+    file_prefix_error = 14
+    globbing_error = 15
+    redundant_inclusion = 16
+    inc_without_sigs = 17
+    no_sigs = 18
+    restore_dir_not_found = 19
+    no_restore_files = 20
+    mismatched_hash = 21
+    unsigned_volume = 22
+    user_error = 23
+    boto_old_style = 24
+    boto_lib_too_old = 25
+    boto_calling_format = 26
+    ftp_ncftp_missing = 27
+    ftp_ncftp_too_old = 28
+    ssh_pexpect_too_old = 29
+    exception = 30
 
-def FatalError(s, code=ErrorCode.generic):
+def FatalError(s, code, extra=None):
     """Write fatal error message and exit"""
-    Log(s, ERROR, code)
+    Log(s, ERROR, code, extra)
+    shutdown()
     sys.exit(code)
 
 class DupLogRecord(logging.LogRecord):
     """Custom log record that holds a message code"""
-    def __init__(self, code, *args, **kwargs):
+    def __init__(self, controlLine, *args, **kwargs):
         global _logger
         logging.LogRecord.__init__(self, *args, **kwargs)
-        self.code = code
+        self.controlLine = controlLine
 
 class DupLogger(logging.Logger):
     """Custom logger that creates special code-bearing records"""
-    # currentCode is a terrible hack until duplicity depends on Python 2.5
+    # controlLine is a terrible hack until duplicity depends on Python 2.5
     # and its logging 'extra' keyword that allows a custom record dictionary.
-    currentCode = 1
+    controlLine = None
     def makeRecord(self, name, lvl, fn, lno, msg, args, exc_info, *argv, **kwargs):
-        return DupLogRecord(self.currentCode, name, lvl, fn, lno, msg, args, exc_info)
+        return DupLogRecord(self.controlLine, name, lvl, fn, lno, msg, args, exc_info)
 
 class OutFilter(logging.Filter):
     """Filter that only allows warning or less important messages"""
     def filter(self, record):
-        return record.levelno <= DupToLoggerLevel(WARNING)
+        return record.msg and record.levelno <= DupToLoggerLevel(WARNING)
 
 class ErrFilter(logging.Filter):
     """Filter that only allows messages more important than warnings"""
     def filter(self, record):
-        return record.levelno > DupToLoggerLevel(WARNING)
+        return record.msg and record.levelno > DupToLoggerLevel(WARNING)
 
 def setup():
     """Initialize logging"""
@@ -130,11 +198,16 @@ def setup():
     _logger = logging.getLogger("duplicity")
     
     # Set up our special level names
-    logging.addLevelName(DupToLoggerLevel(ERROR), "ERROR")
-    logging.addLevelName(DupToLoggerLevel(WARNING), "WARNING")
-    logging.addLevelName(DupToLoggerLevel(NOTICE), "NOTICE")
-    logging.addLevelName(DupToLoggerLevel(INFO), "INFO")
-    logging.addLevelName(DupToLoggerLevel(DEBUG), "DEBUG")
+    logging.addLevelName(DupToLoggerLevel(0), "ERROR")
+    logging.addLevelName(DupToLoggerLevel(1), "WARNING")
+    logging.addLevelName(DupToLoggerLevel(2), "WARNING")
+    logging.addLevelName(DupToLoggerLevel(3), "NOTICE")
+    logging.addLevelName(DupToLoggerLevel(4), "NOTICE")
+    logging.addLevelName(DupToLoggerLevel(5), "INFO")
+    logging.addLevelName(DupToLoggerLevel(6), "INFO")
+    logging.addLevelName(DupToLoggerLevel(7), "INFO")
+    logging.addLevelName(DupToLoggerLevel(8), "INFO")
+    logging.addLevelName(DupToLoggerLevel(9), "DEBUG")
     
     # Default verbosity allows notices and above
     setverbosity(NOTICE)
@@ -152,14 +225,19 @@ class MachineFormatter(logging.Formatter):
     """Formatter that creates messages in a syntax easily consumable by other
        processes."""
     def __init__(self):
-        logging.Formatter.__init__(self, "%(levelname)s %(code)s\n%(message)s")
+        # 'message' will be appended by format()
+        logging.Formatter.__init__(self, "%(levelname)s %(controlLine)s")
     
     def format(self, record):
         s = logging.Formatter.format(self, record)
-        # Indent each extra line with a dot and space so that the consumer
-        # knows it's a continuation, not a new message.  Add a newline so
-        # consumers know the message is over.
-        return s.replace('\n', '\n. ') + '\n'
+        
+        # Add user-text hint of 'message' back in, with each line prefixed by a
+        # dot, so consumers know it's not part of 'controlLine'
+        if record.message:
+            s += ('\n' + record.message).replace('\n', '\n. ')
+        
+        # Add a newline so consumers know the message is over.
+        return s + '\n'
 
 class MachineFilter(logging.Filter):
     """Filter that only allows levels that are consumable by other processes."""
